Euslint
=======

Linter for Euslisp

How to Use
==========

```bash
$ euslint --help
usage: euslint [-h] [-e EXTENSION] [-l MAX_LINE_LENGTH] [-i IGNORE] path

positional arguments:
  path                  checking dir or file path

optional arguments:
  -h, --help            show this help message and exit
  -e EXTENSION, --extension EXTENSION
                        file extension, defalut: l
  -l MAX_LINE_LENGTH, --max-line-length MAX_LINE_LENGTH
                        maximum line length, defalut: 100
  -i IGNORE, --ignore IGNORE
                        list of ignoring check ids.
```
